import javax.xml.registry.*;
import javax.xml.registry.infomodel.*;
import java.net.*;
import java.util.*;

public class JAXRQueryExample {

  public static void main(String[] args){
    Connection conn = null;
    String query = args[0];
    Properties props = new Properties();
    props.setProperty("javax.xml.registry.queryManagerURL",
     "http://www-3.ibm.com/services/uddi/testregistry/inquiryapi");
    props.setProperty("javax.xml.registry.factoryClass",
     "com.sun.xml.registry.uddi.ConnectionFactoryImpl");
    try {
      ConnectionFactory factory = ConnectionFactory.newInstance();
      factory.setProperties(props);
      conn = factory.createConnection();
      System.out.println("Successfully connected to the registry");
      RegistryService service = conn.getRegistryService();
      BusinessQueryManager manager = service.getBusinessQueryManager();
      Collection qualifiers = new ArrayList();
      qualifiers.add(FindQualifier.SORT_BY_NAME_DESC);
      Collection patterns = new ArrayList();
      patterns.add(query);
      BulkResponse response = manager.findOrganizations(
         qualifiers, patterns, null, null, null, null);
      Collection results = response.getCollection();
      if(results.size() == 0){
        System.out.println("No results were returned from this query");
      }
      else {
        System.out.println("There are " + results.size() + " results from this query:");
        System.out.println("");
      }
      Iterator iter = results.iterator();
      while (iter.hasNext()){
        Organization org = (Organization)iter.next();
        System.out.println("Name: " + org.getName().getValue());
        System.out.println("Description: " +
                            org.getDescription().getValue());
        displayServices(org);
        System.out.println("");
      }
    }
    catch(Exception e){
      System.out.println("An error has occurred: " + e);
    }
  }

  public static void displayServices(Organization org){
    try {
      Collection services = org.getServices();
      Iterator iter = services.iterator();
      while(iter.hasNext()){
        Service service = (Service)iter.next();
        System.out.println("Service name: " +
                            service.getName().getValue());
        Collection bindings = service.getServiceBindings();
        Iterator iterTwo = bindings.iterator();
        while(iterTwo.hasNext()){
          ServiceBinding binding = (ServiceBinding)iterTwo.next();
          System.out.println("Service binding: " +
                              binding.getAccessURI());
        }
      }
    }
    catch(JAXRException e){
      System.out.println("A problem occured whilst obtaining services: " + e);
    }
  }

}
